package com.yourcompany.yourcondition;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.os.Bundle;
import android.util.Log;

/**
 * This is the "query" {@code BroadcastReceiver} for a <i>Locale</i> plug-in condition.
 */
public final class QueryReceiver extends BroadcastReceiver
{

	/**
	 * @param context {@inheritDoc}.
	 * @param intent the incoming {@code Intent}. This should always contain the store-and-forward {@code Bundle} that was saved
	 *            by {@link EditActivity} and later broadcast by <i>Locale</i>.
	 */
	@Override
	public void onReceive(final Context context, final Intent intent)
	{
		/*
		 * Always be sure to be strict on your input parameters! A malicious third-party app could always send your plug-in an
		 * empty or otherwise malformed Intent. And since Locale applies settings in the background, you don't want your plug-in
		 * to crash.
		 */
		if (!com.twofortyfouram.Intent.ACTION_QUERY_CONDITION.equals(intent.getAction()))
		{
			Log.w("DisplayCondition", "Received unexpected Intent action"); //$NON-NLS-1$//$NON-NLS-2$
			return;
		}

		final Bundle bundle = intent.getBundleExtra(com.twofortyfouram.Intent.EXTRA_BUNDLE);
		if (bundle == null)
		{
			Log.e("DisplayCondition", "Received null BUNDLE"); //$NON-NLS-1$ //$NON-NLS-2$
			return;
		}
		if (!bundle.containsKey(Constants.BUNDLE_EXTRA_BOOLEAN_STATE))
		{
			Log.e("DisplayCondition", "Missing STATE param in Bundle"); //$NON-NLS-1$ //$NON-NLS-2$
			return;
		}

		if (!BackgroundService.isRunning())
		{
			/*
			 * To detect screen changes as they happen, a service must be running because the SCREEN_ON/OFF Intents are
			 * REGISTERED_RECEIVER_ONLY.
			 */
			final Intent serviceIntent = new Intent(context, BackgroundService.class);
			serviceIntent.putExtras(intent);
			context.startService(serviceIntent);
		}

		final int state = BackgroundService.getScreenState(context);
		if (state == -1)
			setResultCode(com.twofortyfouram.Intent.RESULT_CONDITION_UNKNOWN);
		else if (state == 1 && bundle.getBoolean(Constants.BUNDLE_EXTRA_BOOLEAN_STATE))
			setResultCode(com.twofortyfouram.Intent.RESULT_CONDITION_SATISFIED);
		else if (state == 0 && !bundle.getBoolean(Constants.BUNDLE_EXTRA_BOOLEAN_STATE))
			setResultCode(com.twofortyfouram.Intent.RESULT_CONDITION_SATISFIED);
		else
			setResultCode(com.twofortyfouram.Intent.RESULT_CONDITION_UNSATISFIED);
	}
}